@@ -1,12 +1,5 @@
-//! Type that implements a very simple encoding which utilizes length-prefixed
-//! records where appropriate.
-//!
-//! The simple encoding format uses the following principle:
-//! * Anything with variable length is *length prefixed*. The length is encoded
-//!   using a [variable-length encoder][crate::int::continuation].
-//! * A struct / tuple / variant is length-prefixed with the number of elements
-//!   it contains.
-//! * Each tagged record is prefixed with the tag of the record.
+//! Module that defines [StorageEncoding] whith allows for customization of the
+//! encoding format, and the [DEFAULT] encoding configuration.
 
 use core::marker;
 #[cfg(feature = "std")]
@@ -24,13 +17,20 @@ use musli_binary_common::reader::Reader;
 use musli_binary_common::writer::VecWriterError;
 use musli_binary_common::writer::Writer;
 
-/// Default encoding to use.
-const DEFAULT: StorageEncoding<Variable, Variable> = StorageEncoding::new();
-
-/// Encode the given value to the given [Writer] using [StorageEncoder] with default
-/// settings as defined by [StorageEncoding::new].
+/// The default configuration.
 ///
-/// The default configuration uses [Variable] integer encoding.
+/// Uses variable-encoded numerical fields and variable-encoded prefix lengths.
+///
+/// The variable length encoding uses [zigzag] with [continuation] encoding for
+/// numbers.
+///
+/// [zigzag]: musli_binary_common::int::zigzag
+/// [continuation]: musli_binary_common::int::continuation
+pub const DEFAULT: StorageEncoding<Variable, Variable> = StorageEncoding::new();
+
+/// Encode the given value to the given [Writer] using the [DEFAULT]
+/// configuration.
+#[inline]
 pub fn encode<W, T>(writer: W, value: &T) -> Result<(), W::Error>
 where
     W: Writer,
@@ -39,9 +39,10 @@ where
     DEFAULT.encode(writer, value)
 }
 
-/// Encode the given value to the given [Write][std::io::Write] using
-/// [StorageEncoder] with default settings as defined by [StorageEncoding::new].
+/// Encode the given value to the given [Write][io::Write] using the [DEFAULT]
+/// configuration.
 #[cfg(feature = "std")]
+#[inline]
 pub fn to_writer<W, T>(writer: W, value: &T) -> Result<(), io::Error>
 where
     W: io::Write,
@@ -50,9 +51,9 @@ where
     DEFAULT.to_writer(writer, value)
 }
 
-/// Encode the given value to a [Vec] using [StorageEncoder] with default
-/// settings as defined by [StorageEncoding::new].
+/// Encode the given value to a [Vec] using the [DEFAULT] configuration.
 #[cfg(feature = "std")]
+#[inline]
 pub fn to_vec<T>(value: &T) -> Result<Vec<u8>, VecWriterError>
 where
     T: ?Sized + Encode,
@@ -60,8 +61,9 @@ where
     DEFAULT.to_vec(value)
 }
 
-/// Encode the given value to a fixed-size byte storage using [StorageEncoder]
-/// with default settings as defined by [StorageEncoding::new].
+/// Encode the given value to a fixed-size bytes using the [DEFAULT]
+/// configuration.
+#[inline]
 pub fn to_fixed_bytes<const N: usize, T>(value: &T) -> Result<FixedBytes<N>, FixedBytesWriterError>
 where
     T: ?Sized + Encode,
@@ -69,8 +71,9 @@ where
     DEFAULT.to_fixed_bytes::<N, _>(value)
 }
 
-/// Decode the given type from the given `reader` using [StorageEncoder] with
-/// default settings as defined by [StorageEncoding::new].
+/// Decode the given type `T` from the given [Reader] using the [DEFAULT]
+/// configuration.
+#[inline]
 pub fn decode<'de, R, T>(reader: R) -> Result<T, R::Error>
 where
     R: Reader<'de>,
@@ -193,8 +196,9 @@ where
         }
     }
 
-    /// Encode the given value to the given [Writer] using [StorageEncoder] with
-    /// the current settings.
+    /// Encode the given value to the given [Writer] using the current
+    /// configuration.
+    #[inline]
     pub fn encode<W, T>(self, mut writer: W, value: &T) -> Result<(), W::Error>
     where
         W: Writer,
@@ -203,9 +207,10 @@ where
         T::encode(value, StorageEncoder::<_, I, L>::new(&mut writer))
     }
 
-    /// Encode the given value to the given [Write][io::Write] using
-    /// [StorageEncoder] with the current settings.
+    /// Encode the given value to the given [Write][io::Write] using the current
+    /// configuration.
     #[cfg(feature = "std")]
+    #[inline]
     pub fn to_writer<W, T>(self, write: W, value: &T) -> Result<(), io::Error>
     where
         W: io::Write,
@@ -215,9 +220,9 @@ where
         T::encode(value, StorageEncoder::<_, I, L>::new(&mut writer))
     }
 
-    /// Encode the given value to a [Vec] using [StorageEncoder] with the current
-    /// settings.
+    /// Encode the given value to a [Vec] using the current configuration.
     #[cfg(feature = "std")]
+    #[inline]
     pub fn to_vec<T>(self, value: &T) -> Result<Vec<u8>, VecWriterError>
     where
         T: ?Sized + Encode,
@@ -227,7 +232,9 @@ where
         Ok(data)
     }
 
-    /// Encode the given value to a fixed-size bytes storage.
+    /// Encode the given value to a fixed-size bytes using the current
+    /// configuration.
+    #[inline]
     pub fn to_fixed_bytes<const N: usize, T>(
         self,
         value: &T,
@@ -240,8 +247,9 @@ where
         Ok(bytes)
     }
 
-    /// Decode the given type from the given `reader` using [StorageEncoder] with the
-    /// current settings.
+    /// Decode the given type `T` from the given [Reader] using the current
+    /// configuration.
+    #[inline]
     pub fn decode<'de, R, T>(self, mut reader: R) -> Result<T, R::Error>
     where
         R: Reader<'de>,
